package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.30.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.30.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````)'``````````0```````
M`+&8``````!``#@`"0!``!H`&0````8````$`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0````````"
M.`````````(X`````````C@`````````#P`````````/``````````$````!
M````!0```````````````````````````````````````*3X````````I/@`
M```````0``````$````&````````JY@```````"[F````````+N8````````
M!.@````````5$````````!```````@````8```````"KJ````````+NH````
M````NZ@````````"$`````````(0``````````@````$````!`````````)(
M`````````D@````````"2`````````!$`````````$0`````````!&1TY5``
M```$````````GA````````">$````````)X0`````````/0`````````]```
M```````$9'3E40````8`````````````````````````````````````````
M`````````````````````!!D=.52````!````````*N8````````NY@`````
M``"[F`````````1H````````!&@``````````2]L:6(O;&0V-"YS;RXQ````
M```$````%`````-'3E4`0I`Q=L[GO2-4-=>2_`/RK1*[_Z$````$````$```
M``%'3E4```````````,````"```````````````1````2`````0````(A`1`
M!0`0$""$`(:`!``"*`@$(`D```F""`(`ND40H(@`````````2````$L```!.
M````3P```%8```!7````6````%H```!;````70```%X```!?````8````&(`
M`````````!_?Q6XM1][.?)I_:[:;Q2Y\U&34#N3_(1Q8<=D!QD?B;XL!LL#C
M2ZR'U_I"+#_EPGR2X[I@;*'[UD,):V;,KV?LU45"TW`'B9[B%`WMVV(RGN/-
MV\PEC!4+ESH-FYRI?PH"I^!0GAIK2?O@HP``````````````````````````
M```````````#```+````````&F@``````````````\P2````````````````
M`````````````0P2`````````````````````````````R(1````````````
M`````````````````L$2`````````````````````````````),2````````
M`````````````````````0$1`````````````````````````````H\2````
M`````````````````````````9,2`````````````````````````````B(2
M`````````````````````````````2(2````````````````````````````
M`=T2`````````````````````````````FT2````````````````````````
M`````!$@`````````````````````````````K`2````````````````````
M`````````:H2`````````````````````````````RH2````````````````
M`````````````R$A`````````````````````````````@,2````````````
M`````````````````G02`````````````````````````````5,2````````
M`````````````````````F82`````````````````````````````+02````
M`````````````````````````4,2`````````````````````````````342
M`````````````````````````````O\2````````````````````````````
M`AH2`````````````````````````````"`@````````````````````````
M`````;$2`````````````````````````````L@2````````````````````
M`````````R`1`````````````````````````````IT2````````````````
M`````````````E$2`````````````````````````````#P@````````````
M`````````````````%82`````````````````````````````DD2````````
M`````````````````````8,2`````````````````````````````E\2````
M`````````````````````````',2`````````````````````````````/`2
M`````````````````````````````(02````````````````````````````
M`M@2`````````````````````````````N(B````````````````````````
M`````<P2`````````````````````````````A42````````````````````
M`````````-02`````````````````````````````D,2````````````````
M`````````````E@2`````````````````````````````742````````````
M`````````````````6<2`````````````````````````````182````````
M`````````````````````BL2`````````````````````````````M$2````
M`````````````````````````GH2`````````````````````````````PX2
M`````````````````````````````CP2````````````````````````````
M`>,2`````````````````````````````)\2````````````````````````
M`````?X2`````````````````````````````9X2````````````````````
M`````````1$2`````````````````````````````?<2````````````````
M`````````````.,1`````````````````````````````P<2````````````
M`````````````````O$2`````````````````````````````5P2````````
M`````````````````````J@2`````````````````````````````&02````
M`````````````````````````H@2`````````````````````````````KH1
M`````````````````````````````,(2````````````````````````````
M`]42```-````````1A``````````F@``!#H2```-````````./`````````(
M^````QL2```-````````(A`````````"7@```SP2```-````````,%``````
M````!@```VH2```-````````0?`````````$$@``!&`2```-````````,&``
M```````"Q@``!"`0```7````````P(```````````````TT2```-````````
M,S``````````4````X`2```-````````-I``````````G````^$1```/````
M````8(P`````````!````_T2```-````````74`````````!(@``!`@2```-
M````````+K``````````/```!#40```7````````T*@`````````````!$X2
M```-````````-V`````````!@@```_`0```6````````P```````````````
M`Z02```-````````,X`````````!;@``!$<0```6````````P(``````````
M````!&T1```6````````P'@`````````"````UH2```-````````8$``````
M`````@```_82```-````````)'``````````````!!`2```-````````7]``
M````````8@``!"P2```-````````7-``````````;````_(@```6````````
MP````````````````[H2```-````````-S``````````+````XX2```-````
M````+U``````````_````[`2```-````````7G`````````!5```!'<2```-
M````````-/`````````!H`!L:6)P97)L+G-O+C4N,S``7U]G;6]N7W-T87)T
M7U\`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%])5$U?<F5G:7-T97)4
M34-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L
M7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?
M8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA
M9W,`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA
M9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O
M<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?
M<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O
M;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P
M97)L7V%L;&]C`&QI8G!T:')E860N<V\N,`!?7V5R<FYO7VQO8V%T:6]N`&-L
M;W-E`'!T:')E861?9V5T<W!E8VEF:6,`;W!E;C8T`')E860`;'-E96LV-`!L
M:6)C+G-O+C8`97AI=`!S=')N8VUP`&-L;W-E9&ER`%]?<W1A8VM?8VAK7V9A
M:6P`=6YL:6YK`&UK9&ER`')E86QL;V,`;65M8VAR`&=E='!I9`!S=')D=7``
M<W1R=&]K`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T
M<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R
M`&=E='5I9`!R96%D;&EN:P!S=')C:'(`<F5A9&1I<C8T`%]?8WAA7V9I;F%L
M:7IE`%]?<W!R:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`7U]L:6)C7W-T87)T
M7VUA:6X`7U]E;G9I<F]N`%]?<F5G:7-T97)?871F;W)K`'!A<E]C=7)R96YT
M7V5X96,`<&%R7V)A<V5N86UE`%]?;&EB8U]C<W5?9FEN:0!84U]);G1E<FYA
M;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R
M;V,`<&%R7V1I<FYA;64`<VAA7V9I;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E
M='!W=6ED`'!A<E]C;&5A;G5P`%])3U]S=&1I;E]U<V5D`%]?9&%T85]S=&%R
M=`!S:&%?=7!D871E`'AS7VEN:70`7U]L:6)C7V-S=5]I;FET`%]?8G-S7W-T
M87)T`'-H85]I;FET`%]E;F0`<&%R7VUK=&UP9&ER`%]E9&%T80!P87)?<V5T
M=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`;7E?<&%R7W!L`'!A<E]I;FET7V5N
M=@!'3$E"0U\R+C(`1TQ)0D-?,BXT`$=,24)#7S(N,RXR`$=,24)#7S(N,RXT
M`````````@````(``@```````P````(````$``(````"``(`!0`"``0``@``
M``(``````````@`"```````"``(``@`"```````"`````@`````````"``(`
M!``"`````@`"``````````8``@`&``(``@`$````!`````(`!`````(`!@``
M``(````"``(````!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0````$``0```;P````0````(`UI:1(````$
M```$A````````0`$```""P```!``````#6EI%`````8```2.````$`EI&7(`
M```%```$F````!`):1ET`````P``!*0````0#6EI$@````(```2$````````
M`````+N8``````````P````````ED````````+N@``````````P````````E
M0````````+_X``````````P````````B$````````,`(``````````P`````
M``#`"````````,`8``````````P```````!@D````````,`@``````````P`
M``````!@E@```````,`P``````````P```````!@F````````,`X````````
M``P```````!@G````````,!```````````P```````!@I````````,!(````
M``````P```````!A(````````,!0``````````P```````!@K````````,!@
M``````````P```````!@L````````,!H``````````P```````!@M@``````
M`,!X``````````P```````!C@@```````+^@````!`````H`````````````
M`````+^H````!P````H``````````````````+^P````"P````H`````````
M`````````+^X````#@````H``````````````````+_`````'`````H`````
M`````````````+_(````(@````H``````````````````+_0````)0````H`
M`````````````````+_8````)P````H``````````````````+_@````*P``
M``H``````````````````+_H````/P````H``````````````````+_P````
M1@````H``````````````````+W0`````@````L``````````````````+W8
M`````P````L``````````````````+W@````!0````L`````````````````
M`+WH````!@````L``````````````````+WP````"`````L`````````````
M`````+WX````"0````L``````````````````+X`````"@````L`````````
M`````````+X(````#`````L``````````````````+X0````#0````L`````
M`````````````+X8````#P````L``````````````````+X@````$`````L`
M`````````````````+XH````$0````L``````````````````+XP````$P``
M``L``````````````````+XX````%`````L``````````````````+Y`````
M%0````L``````````````````+Y(````%@````L``````````````````+Y0
M````%P````L``````````````````+Y8````&`````L`````````````````
M`+Y@````&0````L``````````````````+YH````&@````L`````````````
M`````+YP````&P````L``````````````````+YX````'0````L`````````
M`````````+Z`````'@````L``````````````````+Z(````(`````L`````
M`````````````+Z0````(0````L``````````````````+Z8````(P````L`
M`````````````````+Z@````)`````L``````````````````+ZH````)@``
M``L``````````````````+ZP````*`````L``````````````````+ZX````
M*0````L``````````````````+[`````*@````L``````````````````+[(
M````*P````L``````````````````+[0````+`````L`````````````````
M`+[8````+0````L``````````````````+[@````+@````L`````````````
M`````+[H````+P````L``````````````````+[P````,`````L`````````
M`````````+[X````,0````L``````````````````+\`````,@````L`````
M`````````````+\(````,P````L``````````````````+\0````-`````L`
M`````````````````+\8````-0````L``````````````````+\@````-@``
M``L``````````````````+\H````-P````L``````````````````+\P````
M.`````L``````````````````+\X````.0````L``````````````````+]`
M````.@````L``````````````````+](````.P````L`````````````````
M`+]0````/`````L``````````````````+]8````/0````L`````````````
M`````+]@````/@````L``````````````````+]H````0`````L`````````
M`````````+]P````00````L``````````````````+]X````0@````L`````
M`````````````+^`````0P````L``````````````````+^(````1`````L`
M`````````````````+^0````10````L``````````````````+^8````1P``
M``L``````````.MO\#``)+D$`!^G^_]@XQ#P```DP,```%&>P!```%*;XQ`0
M```$N0(`$:>$``,-X>-`\1``!.MO\-``!`?T!P?C$/`X`"3`$```4872!_`P
M$`CC$!`0``0'\0<`!P`'`,`0``!1A.,0$```!`?Q#1#C$!`,`!3`]/___^4`
M````P!```%%XXQ`0```$!_$-$.,0$`P`%,#T____U0```!C`$```46SC$!``
M``0'\0T0XQ`0#``4P/3____%````,,`0``!18.,0$```!`?Q#1#C$!`,`!3`
M]/___[4```!(P!```%%4XQ`0```$!_$-$.,0$`P`%,#T____I0```&#`$```
M44CC$!````0'\0T0XQ`0#``4P/3___^5````>,`0``!1/.,0$```!`?Q#1#C
M$!`,`!3`]/___X4```"0P!```%$PXQ`0```$!_$-$.,0$`P`%,#T____=0``
M`*C`$```423C$!````0'\0T0XQ`0#``4P/3___]E````P,`0``!1&.,0$```
M!`?Q#1#C$!`,`!3`]/___U4```#8P!```%$,XQ`0```$!_$-$.,0$`P`%,#T
M____10```/#`$```40#C$!````0'\0T0XQ`0#``4P/3___\U```!",`0``!0
M].,0$```!`?Q#1#C$!`,`!3`]/___R4```$@P!```%#HXQ`0```$!_$-$.,0
M$`P`%,#T____%0```3C`$```4-SC$!````0'\0T0XQ`0#``4P/3___\%```!
M4,`0``!0T.,0$```!`?Q#1#C$!`,`!3`]/___O4```%HP!```%#$XQ`0```$
M!_$-$.,0$`P`%,#T___^Y0```8#`$```4+CC$!````0'\0T0XQ`0#``4P/3_
M__[5```!F,`0``!0K.,0$```!`?Q#1#C$!`,`!3`]/___L4```&PP!```%"@
MXQ`0```$!_$-$.,0$`P`%,#T___^M0```<C`$```4)3C$!````0'\0T0XQ`0
M#``4P/3___ZE```!X,`0``!0B.,0$```!`?Q#1#C$!`,`!3`]/___I4```'X
MP!```%!\XQ`0```$!_$-$.,0$`P`%,#T___^A0```A#`$```4'#C$!````0'
M\0T0XQ`0#``4P/3___YU```"*,`0``!09.,0$```!`?Q#1#C$!`,`!3`]/__
M_F4```)`P!```%!8XQ`0```$!_$-$.,0$`P`%,#T___^50```EC`$```4$SC
M$!````0'\0T0XQ`0#``4P/3___Y%```"<,`0``!00.,0$```!`?Q#1#C$!`,
M`!3`]/___C4```*(P!```%`TXQ`0```$!_$-$.,0$`P`%,#T___^)0```J#`
M$```4"CC$!````0'\0T0XQ`0#``4P/3___X5```"N,`0``!0'.,0$```!`?Q
M#1#C$!`,`!3`]/___@4```+0P!```%`0XQ`0```$!_$-$.,0$`P`%,#T___]
M]0```NC`$```4`3C$!````0'\0T0XQ`0#``4P/3___WE```#`,`0``!/^.,0
M$```!`?Q#1#C$!`,`!3`]/___=4```,8P!```$_LXQ`0```$!_$-$.,0$`P`
M%,#T___]Q0```S#`$```3^#C$!````0'\0T0XQ`0#``4P/3___VU```#2,`0
M``!/U.,0$```!`?Q#1#C$!`,`!3`]/___:4```-@P!```$_(XQ`0```$!_$-
M$.,0$`P`%,#T___]E0```WC`$```3[SC$!````0'\0T0XQ`0#``4P/3___V%
M```#D,`0``!/L.,0$```!`?Q#1#C$!`,`!3`]/___74```.HP!```$^DXQ`0
M```$!_$-$.,0$`P`%,#T___]90```\#`$```3YCC$!````0'\0T0XQ`0#``4
MP/3___U5```#V,`0``!/C.,0$```!`?Q#1#C$!`,`!3`]/___44```/PP!``
M`$^`XQ`0```$!_$-$.,0$`P`%,#T___]-0``!`C`$```3W3C$!````0'\0T0
MXQ`0#``4P/3___TE```$(,`0``!/:.,0$```!`?Q#1#C$!`,`!3`]/___14`
M``0XP!```$]<XQ`0```$!_$-$.,0$`P`%,#T___]!0``!%#`$```3U#C$!``
M``0'\0T0XQ`0#``4P/3___SU```$:,`0``!/1.,0$```!`?Q#1#C$!`,`!3`
M]/___.4```2`P!```$\XXQ`0```$!_$-$.,0$`P`%,#T___\U0``!)C`$```
M3RSC$!````0'\0T0XQ`0#``4P/3___S%```$L,`0``!/(.,0$```!`?Q#1#C
M$!`,`!3`]/___+4```3(P!```$\4XQ`0```$!_$-$.,0$`P`%,#T___\I0``
M!.#`$```3PCC$!````0'\0T0XQ`0#``4P/3___R5```$^,`0``!._.,0$```
M!`?Q#1#C$!`,`!3`]/___(4```40P!```$[PXQ`0```$!_$-$.,0$`P`%,#T
M___\=0``!2C`$```3N3C$!````0'\0T0XQ`0#``4P/3___QE```%0,`0``!.
MV.,0$```!`?Q#1#C$!`,`!3`]/___%4```58``````````#K;_`P`"2R3P`0
MX_#_./]QXS#PJ``DXT#PH``D4"#PM.L1`"``#;)/`!%!0/"@T@?PP!`H03#P
MJ$$@\+3`Y?___Z[$2```3J_$*```3L"Y!``TP.4``![WQ!@``$[`E0`0`*>$
M`+?$N```3IGC(+```!;`Y?___O.Y!``2XR"P```6E@(4BL#E___^Z5@0\+26
M`22*["$`!0#8N10`(NLB``,`#<#E____"N,P\*@`!,`0``!.YN5,$```!.,0
M,```!%BP\+3C$"```"3`$```($_C$"`(`"3$&```3LC$*P``3M'C$"`0`"3`
M$```($+C$"`8`"2Y!`!2[+P`&P%^03`P"*<(``7L2___`-CC(#````2Y%``0
MZQ$``P`-XR%?^/\DIPH``:<[``BG1O_QQ"@``$ZP[!L`!`#8N10`$>L1``,`
M#>,17_C_<>5($````.Q+``,`V*=I``"Y%`!$P#````7`P.7___OY&++L*`!*
M`'[$*```3HY!H/"\P.7___W]N00`.L`@```>ZL#E```!`>PH`$``?,0H``!.
M>\#E___[G,#E___]&;)/`!"Y%``KZQ$`(``-LD\`$=4'\,`0**=T`$7K;_#X
M``0'_L#E___\Q,0K``!.7>PH`#P`?,#E___].\2X``!-V.,@L```%L#E___^
M,I(`*B&G]/\WQ"@``$Y'P.7___PX&+*G]/^RP!```$XZXR`0```"IX0`!\#E
M```0[J?T_[BY!``ZP"```!YMP.4```"LQ"L``$XE["C_JP!\I_3_[<#E___]
MM:<I``'`Y?___4`'!T%`\`CC,/````2G"?_PN8``\*?[_U#7!_``\`#K[_"@
M`"1!</"@P&```!W5P%```!V:P"```$VKXR`@```$P.7___V]```'!P<'!P<'
M!P<'P!```$W@P"```$W=[!(`"H!DQ!@``$UW[!@`!`!\!_$'_@<'!P<'!P<'
M!P<'!P<'P"```$W(P!```$W%N0D`$NLA``,`"NLQ`#\`#+D(`#+K,P`!``KL
M.``-`'S$&```35;L&``'`'S`(```3:P'\0?^!P<'!P<'!P<'!P<'!P?KO_!8
M`"3`L```39WC\/]@_W&5`+``IW0`%<`0``!-0^,0$````J>$``C$*```34_`
MY?___)S`Y?___Z62`;``Z[_P^``$!_X'!P<'!P<'!\#T____L`<'!P<'!P<'
M!P?K;_`P`"3C\/]8_W'L*`!?`'S$&```3/?C<!````*GA`!6N00`@N,@(```
MD+D$`&.Y!`"8&!+L*`!2`'Q"$/"GE3WPIZ>$``OC()`!`)!!D)`!&!+L)O_T
M`'P;F..@<````J>$`!^Y%`"9N00`M[D$`$FY!``XN00`*L#E___[E^PF``D`
M?D$9H`"5/1``IX0`#T&PL`CCH+````*G=/_IN00`*NMO\-@`!`?^N>EP&T&I
MH`'K$0`#``I0$&``N00`*NMO\-@`!`?^IZD``+D$`"KK;_#8``0'_J>8``"G
M]/^_!P<'!P<'!P<'!P<'!P?KK_!0`"2R3P`0X_#_4/]QZQ$`(``-LD\`$;D$
M`++2!_"H$"A!H/"DN00`.KD$`"O`Y?___W#L*``M`'S$.```3&KC$/"D`!3K
M$0`#``WC$#````CC,!`(``3C,!```"3L./_D`'SC,!`0``1!$!`(XS`0```D
M[#;_^`!\N00`.KD$`"O`Y?___T;L)O_9`'RR3P`0ZQ$`(``-LD\`$=4'\*@0
M**=T``;KK_$```0'_L#E___\1`<'!P<'!P<'!P?K;_`P`"2R3P`0X_#_0/]Q
MZQ$`(``-LD\`$;D$`++2!_"X$"BY!`"CE3TP`*=T``1!H#`!ISD``.P:/+\`
M5:>$`'FG*0`/N0D`(><"H```-Z<[`!#G```P`(&GA``,YP.@```&ISL`$.<`
M`#``@:=T__CG$``'`"&YA``1N2``$D$@(`&YXB`RIR0`5.,3'_#_<4$P\+3C
M$/"H`"2Y!``KP.7___[8N00`,NPH`$L`?*<I``#L$SR_`%6GA``_ITD`#[D)
M`$'G!#```#>G*P`0YP``,`"!IX0`#.<",```!J<K`!#G```P`(&G=/_XYQ``
M!P`AN80`$;D@`!1!0$`!N>(@)*<D`!KC$A_P_W'C(/"H``3L$@$9H&7CD/"T
M`!3$B```2YCKF0`#``VG]`!0IRD`#Z?T_Y6G20`/I_3_S\2(``!+B..0@```
M!.,0D````J>$`.VY!``9IV@``!@FIVH``4$0$`CC,!````*G=/_XIRH``[D4
M`"+K(@`#``W`$```2]SC$!```!*GA`"GN00`,KD$`"G`Y?__^I#C((```"2Y
M!`!R["@`RP!\N10`UNN=``,`#>O=``,`#4$=<`CE2!````!08/"TXR"P``"0
MN00`&Q@R["8`#@!\I_0`G>,@$`$`D$$0$`$8,NPH``D`?$(P\*>5/?"GIW3_
M\[D)`!NY%``1XR#PJ``$XY"````(02(0`L#E___Y4.,@D```).PH`(T`?.,P
M@```!.,@L```D.,0\+0`%.L1``,`#>,1,```!$&PL`%"(!``&#+L)@`0`'RG
M]`!DXR"P``"00;"P`4(@$``8,NPH`"\`?$(P\*>Y!`!1E3WPIT$0$`&G=/_M
MDCU0`*<I``#C,J```)!",A``IRL``>PV__D`?*<H``"R3P`0N10`(NL1`"``
M#;)/`!'5!_"X$"BG=``]ZV_P\``$!_Y!(%`"N00`4;D$`!*G]/_8P!```$LO
MY4P0```!P.7___CIN00`<NPH`"<`?+D$`#FY%`#6ZYT``P`-N00`2<#E___Y
M:.-P@```)*?T_U*G&0``I_3_=KD$`%%!$!`!I_3_KZ<I`!"G:```I_3_)L#E
M___ZH*<H__^G]/^RIQD``.,AH```D$(A,`"G&P`![";_^0!\I_3_H@<'!P<'
M!P<'!P<'!P<'ZV_P,``DLD\`$./P_L#_<>L1`"``#;)/`!'2!_$X$"CL*``)
M`'RY!`!BE0`@`*=T`!*R3P`0ZQ$`(``-LD\`$=4'\3@0**=T`('K;_%P``0'
M_L#E___[.[D$`++L*/_K`'S`D```&L_LACR_`%5!</"HN00`*\#E___YJ>PH
M`%8`?$&@(!/E5"`3+@"GA/_SU0*0`"`3IX3_[J<Y``#LB`!1`'RG20`/N0D`
M2.<$8```-Z<[`!#G```P`(&GA``,YP-@```&ISL`$.<``#``@:=T__CG$``'
M`"&YA``1N2``%$%`0`&YXB`TIR0`*^-3'_#_<:=)``#L&CR_`%6GA``HISD`
M#[D)`#'G`Z```#>G2P`0YP``,`"!IX0`'N<$(!,`!J?T__:Y!``KP.7___?.
MN00`)L#E___X.:?T_WNG20`/I_3_OL#E___YX*<Y``^G]/_FYQ``!P`AN80`
M$;D@`!-!,#`!N>(@0Z<D__'C)!_P_W$:):<J``*Y%``BP.7___?DXZ#PH``D
MITG__[D$`**G.0`!P%```!HVP.7___IUN00`1[D$`#JG*0`!P.7___>\["@`
M#?]^6!#PP*<H0`#`&P``\`#L$@`/@':Y!``JP.7___G:N00`*L#E___Z):?T
M_T>Y!``JP.7___\*I_3_]`<'!P<'!P<'!P>R3P`0Z[_P6``DZQ$`(``-LD\`
M$>/P_LC_<;D$`++2!_$P$"BY!``R04#PH*<I``'`Y?__^%SL)@`A`'X8$E@@
M\+BG.$``P"L``/``[",`"(!VI3^@`.PC`!-@=KD$`"NG.0`"P.7___H"$!*G
M&O__B!``'Z?T``2G&```LD\`,+D4`"'K,P`@``VR3P`QU0?Q,#`HIW0`!NN_
M\9``!`?^P.7___DT!P<'!P<'!P<'!^M_\#@`)./P\`#_<>,`__@`(+)/`!#C
M\/]8_W'K$0`@``VR3P`1XT#PH`%QT@=``!`HN00`HT&0\*"Y!`"RN00`.:=)
M#__`(```&8K`Y?__]^;L+`!?`'[$.```2/#L$O__`-A8<#``N10`@4$X\*"5
M`#``IW0`,NP8`#X`?KD$`$BY!``IISD`+\#E___WY^PH`#(`?+D6`"?`Y?__
M^2^Y!`!8N00`2;D$`#O`Y?__^':R3P`0XR#PH`%QZQ$`(``-LD\`$=4'(``0
M**=T`#7K?_#@`00'_KD4`(*G.0`ON00`2+D$`"G`Y?__][CL)O_4`'RY%@`G
MP.7___D`N00`2KD$`#O`Y?__]TFG]/_3Q!@``$B46'`0`+D6`"?`Y?__^.VY
M!`!*N00`.\#E___W-J?T_\#`Y?__^)$'!P<'Z^_P<``DQ!@``$AYX_#_8/]Q
MXR`0```6P.7___C0Q$@``$B!P%```#>(P#```!D`Z^_Q$``$P/3___E!!P<'
M!^MO\#``),2X``!(6>/P_UC_<>,@L```%L!@```:.,#E___XK<#E____SN,@
ML```%L#E___XI.5(\*```+D$`%;`0```"6#`,```&.#`Y?__]X;K;_#8``0'
M_@<'!P<'!^MO\#``)./P\`#_<>,`__@`(./P\`#_<>,`__@`(+)/`!#C\/](
M_W'K$0`@``VR3P`1XR#PL`)QT@<@`!`HP.7___?=P!```!C"XQ#PH``D0;#P
MKKD$`&*G21`!ISD``;D$`"O`4```&*S`Y?__^,?CD/"O`7&Y!``KN00`.:=)
M$`#`Y?__]MOL)``S`'ZY!`"RIRH``;D4`"+`Y?__]@^Y!`"B["@`$`!\N10`
MN[D$`#FY!`!+P.7___CA01N@`)(`$`"R3P`0XR#PL`)QZQ$`(``-LD\`$=4'
M(``0**=T``RY!``JZV_PZ`($!_ZGJ0``I_3_Z<#E___WP0<'!P?`]/___X`'
M!P<'!P<'!P<'ZV_P,``DX_#P`/]QXP#_^``@LD\`$./P_K#_<>L1`"``#;)/
M`!&Y!`"2XR#Q2`%QN00`HT$P\+32!R``$"C`(```&#_`Y?__^GZG.0`ON00`
MLKD$`"G`Y?__]YGL*``@`'RY!``YP"```!@PP.7___M"N00`*;)/`!#C,/%(
M`7'K$0`@``VR3P`1U0<P`!`HIW0!&.MO\8`!!`?^ISD``.P9/+\`5:>$`)JG
M*0`/N0D`(><"D```-Z<[`!#G```P`(&GA``,YP.0```&ISL`$.<``#``@:=T
M__CG$``'`"&YA``1N2``$D$@(`&YXB`RIR0`=;D$`"KCHQ_P_W'`,```%^O`
MY?__]:*Y!`!B["C_J@!\IZH``4&`\4A!</"XE0!@`*>$`'3LN``/`'RG"```
MN00`%KD$`"NR70`2IQ3__J>$`%2G.0``[!8\OP!5IX0`M*<I``^Y"0`AYP)@
M```WISL`$.<``#``@:>$``SG`V````:G.P`0YP``,`"!IW3_^.<0``<`(;F$
M`!&Y(``202`@`;GB(#*G)`"/XR,?\/]Q&!*Y%``BXR)O__]QE2\@`*=T`#BG
M&O__N10`,4$C8`"2`"``XR-O__]QE2\@`*>$__.G]``GIRD`#Z?T_W25`+`!
MIW0`&L`P```7=:<I``#`Y?__]2JY!`!B["C_,@!\E0!@`*=T_Y#LN``'`'R5
M+K``IX3_YL!@```7#J<8``$:&J<H#__L$O\<(';CD/"H`"3`$```%U#C$/"@
M`"2G21``ISD``;D$`"C`4```%Z[`Y?__]TJY!`!'N00`.*<I``'`Y?__])'L
M)O^_`'Y8$/#0I2^``,`;``#P`.P2_[5@=KD$`"BG.0`!P.7___<=[";_JP!^
MN00`.,`@```7%,#E___Z)KD$`"C`Y?__]8VG]/[AIRD`#Z?T_UK`Y?__]E0'
M!P<'!P<'!P<'N00`$N,@(```D.PH`"``?+/!``_C\/]8_W'C`/"@`"`80KD$
M`"%"0/"GXS`0`0"0E2_PIT$0$`$80[GB@"'L-O_T`'RSS0#P!_ZY!``A!_[L
M*`!4`'R5`"``IX0`3Z<Y``#L$CR_`%6GA`!$ITD`#[D)`$'G!"```#>G.P`0
MYP``,`"!IX0`#.<#(```!J<[`!#G```P`(&G=/_XYQ``!P`AN80`$;D@`!1!
M0$`!N>(@-*<D`!_C$Q_O_W&Y"``2N>D@0>PA`'B@994O$`"G=``;XQ`?__]Q
MIT?_^94O$`"GA``,P"```!:1P/3___4'ITD`#Z?T_\K`(```%C?`]/__]/VY
MZ2!!["$`5J!EXQ`?__]QIT<`!*?T_^*5+Q``IW3_][GI($'C,!___W'L(P`N
M(&7L*``K_WSC$!___W&G1P`IN0D`$J=)$`#L,0`"`-GL-``N(&7K[_!P`"2Y
M!``RX_#_8/]Q04`0`:=9$`#`(```1@3`Y?__\U'`(```1?[K[_$0``0'_J=)
M``&G]/_6E2\0`*>$_]*Y"0`2ITD0`.PQ``(`V>PT_]C`9:<I```'_NPA_[A@
M9*?T_Y$'!^N_\%@`)+)/`!#C\/\P_W'K$0`@``VR3P`1P#```#1MT@?PR!`H
MTB'PIC`*P"```!8.0;#PH,#E___XM<`@```6"\#E___XK\`@```6"<#E___X
MJ<`@```6",#E___XH\`@```6!L#E___XG<`@```6",#E___XE\`@```5VL#E
M___XD<`@```6`L#E___XB\`@```6`<#E___XA<`@```6`,#E___X?\`@```5
MQ\#E___X>;D$`#O`(```%??`Y?__]_GL*``+`'RY!``RP"```!7BP.7___C&
MN00`.\`@```5[<#E___WYKD$`#+L*``)`'S`(```%5K`Y?__^+.Y!``[P"``
M`!7CP.7___?3N00`,NPH`"(`?,`@```5B<#E___XH,`P```5Z<`@```5H,#E
M___XE[)/`!#K$0`@``VR3P`1U0?PR!`HIW0`)^N_\2@`!`?^N00`.\`@```5
MO\#E___WI[D$`#+L*``+`'S`(```%8O`Y?__^'2G]/_4P!```!6UU0D0`/"W
MIW3_S$$P\,&G]/_NP.7___2?Z^_P<``DLD\`$./P_U#_<>L1`"``#;)/`!'$
M+0``1+/2!_"H$"CL*``5_WZR3P`0N10`(NL1`"``#;)/`!'5!_"H$"BG=``I
MZ^_Q(``$!_Y!,/"DP"```!5*P.7___=;["@`%P!\XQ`@``"0E0`@`*>$``_`
M%P```#"Y`P`A["(_OP%9Q"\``$1^I_3_T:<H``"G]/_YP.7___11!P<'!^OO
M\'``)./P_V#_<<#E___QYL#E___QP^PH``8`?.,@(```!.OO\1``!`?^!P<'
M![)/`!#K;_`P`"3K$0`@``VR3P`1X_#_0/]QN00`8M('\+@0*$$P\+3`(```
M%3'`Y?__]PFY!``V["@`"0!\N00`LI4`(`"G=``8P"```!4@P.7___?0LD\`
M$.L1`"``#;)/`!'5!_"X$"BG=`!7ZV_P\``$!_[`Y?__\?GL)O_M`'SL%CR_
M`%6GA`!$ISD`#[D)`#'G`V```#>G*P`0YP``,`"!IX0`#.<"8```!J<K`!#G
M```P`(&G=/_XYQ``!P`AN80`$;D@`!-!,#`!N>(@(Z<D`!_C0A_P_W&G.0``
M[!L\OP!5IX0`'*<I``^Y"0`AYP*P```WISL`$.<``#``@:>$`!+G`[````:G
M]/_VISD`#Z?T_\K`Y?__\ZBG*0`/I_3_\N<0``<`(;F$`!&Y(``202`@`;GB
M(#*G)/_QXQ,?\/]Q0200`L#E___QK^.P\*@`),`0```4/^,0\*``)+D$`+*G
M.0`!P%```!2@ITG__\#E___T.KD$`#NG]/]F!P<'!P<'!P<'!P<'!P?K;_`P
M`"3CX/``^''C\/``_W'C`/_X`""Y(0#^IR3_^+)/`!#`0```0W[K$0`@``VR
M3P`1N00`_N/P_@#_<>,P\?@(<4&`\,32!S``$"C2#_#(0`C2!_#80!C2+_#X
M0"#2#_#@0%#2!_#P0&"Y!`"2N00`.,`@```3W,#E___V&^PH``D`?+D$`+*5
M`"``IW0!&,#E___^U[D$`++L*`#7`'RG*0``[!L\OP!5IX0`RZ<Y``^Y"0`Q
MYP.P```WIRL`$.<``#``@:>$``SG`K````:G*P`0YP``,`"!IW3_^.<0``<`
M(;F$`!&Y(``303`P`;GB(".G)`"FXR(?\/]QZR(``0`-IRL``<#E___Q!^,0
ML```D+D$`'(88>P8`!X`?+D$`*>Y!``JN80`9L!0```3\J=)__^G.0`!P.7_
M__..XQ"P`0"00;"P`4&@H`(88>P6_^H`?$&@\0#`(```$R:G]``)IZL`".,@
MK_C_`J>$`,:Y!``XP.7___6<N00`LNPH__(`?)4`(`"GA/_MP.7___D@["C_
MZ`!^N00`*\#E___QS+D$`&+L*`"I`'RG*0``[!8\OP!5IX0`V*<Y``^Y"0`Q
MYP-@```WIRL`$.<``#``@:>$``SG`F````:G*P`0YP``,`"!IW3_^.<0``<`
M(;F$`!&Y(``303`P`;GB(".G)`"SX[(?\/]QISD``.P7/+\`5:>$`+"G*0`/
MN0D`(><"<```-Z<[`!#G```P`(&GA`"FYP-P```&I_3_]J<Y``^G]/]#IZ@`
M`+D4`!KK$0`#``WC(?#@``*GA``BN00`.*>J``'`Y?__]2/L*/_O`'R5`"``
MIX3_ZL#E___Q7;D$`++L)O\-`'RY%``:ZQ$``P`-XR'PX``"IW3_XJ<I``W`
ML```$S+`Y?__\#:G:`!3N00`<J?T_S3`Y?___=FY!``KP.7___$XN00`LK)/
M`!#C(/'X"''K$0`@``VR3P`1U0<@`!`HIW0`0[D$`"OK;_(P"`0'_J>H``"Y
M%``:ZQ$``P`-X['PR``"IX0`))4`L`"GA``@N00`*Z>J``'`Y?__^%;L*/_K
M`'ZY!``KP.7___$"N00`8NPF_SD`?+D4`!KK$0`#``WCL?#(``*G=/_@IVD`
M`*<I``#L%CR_`%6G=/\LISD`#Z?T_S;`Y?__\;.G*0`/I_3_7N<0``<`(;F$
M`!&Y(``202`@`;GB(#*G)/_QXQ,?\/]Q&K&GN@0$N10`N[D$`"O`Y?__[[7C
M</"P`"3`$```$K3C$/"H`"3`$```$D#C$/"@`"2Y!`!RISD``<!0```2GZ=)
M___`Y?__\CJY!``GISD!P,#E___Q(^PF``O_?L#E___P[5@0(`#L%@%1$7ZY
M!``W04#Q**<I``'`Y?__\$\8HNPF``T`?E@0\4"G*$``P!L``/``[!(`&H!V
MQ!@``$%BXU"0```$XR`0```$N00`9\!````2B:<Y``&GN0``P.7___%<I_3_
M-EA@\43`Y?__[M7L8O_D8'98$/%`IR@!P,`;```!_^P2_]I@=KD$`"O`Y?__
M[T.Y!``XN00`LL`@```2C,#E___T!>PH`/$`?..`D```!,#E___P0+D$`#*Y
M!``HP.7___E5N00`@NPH`-\`?*<I``#L&#R_`%6GA`#AISD`#[D)`#'G`X``
M`#>G*P`0YP``,`"!IX0`#.<"@```!J<K`!#G```P`(&G=/_XYQ``!P`AN80`
M$;D@`!-!,#`!N>(@(Z<D`+SC(A_P_W'L+``A`WZY%``2P#```!)`XQ&/_/]Q
MIP@``+)=`#&G%/_^IW0`$.PH`5,$?J<J__RY%``BXQ*/__]QE2\0`*>$`4?`
MY?___!7L)@`0`'ZY!``HISD``,#E___Q1[D$`)(8@NPF`*8`?L`P```1KL`@
M```1<\#E___T7,#E___P5<`0```2:N,@\*@`).,0\+``),`0```10.,0\*``
M)+D$`&>Y!``KP%```!(`ITG__Z<Y``'`Y?__\3BG]``RP.7__^_S6!`@`*<>
M`!&G=``SP.7___`JIZH``;D4`!KC$/"P`"3C(/"H`"3`$```$C7C$/"X`"3`
M$```$0[C$/"@`"2Y!`!GN00`*\!0```1U:=)__^G.0`!P.7___$&N00`*Z<Y
M`<#`Y?__[^_L*/_)_WZY!``GP.7___#'N00`.\`@```0W,#E___S\[D$`"O`
MY?__^_:G]/XDXX"0```$IRD``.P8/+\`5:=T_R.G.0`/I_3_+<0H``!`*[D4
M`!'C$/"@`"3C4)````3C("````2Y!`!GP$```!$OISD``<#E___P(J>Y``"G
M]/WZITD``J<Y_^[`Y?__[C=!H/'XN00`*;D$`#JG20`&P.7___!<E0#Q^*=T
M``:50_'YIX0`PKD$`"FG20``ISD``+D4`)C`Y?__[AG`Y0``#EJY!`""I_0`
M"[D$`#JY!``HN10`1,#E```.A:5/@`"Y!``ZN00`*<#E___P,+D$`$+L(O_L
M`'Y!H/&[N00`*4&0\<_`Y?__[:*Y!``XN00`*L#E```._[D$`(JGJ0`4XV"`
M``"0N00`*:>+``&GFP`"P%```!"XITG__Z<Y``'`Y?__\%2GI__MP!```!%G
MD@#Q]^,0\+``)$$0\<_C$/"H`"2Y!`!GN00`*\`0```0->,0\*``),!0```0
M\:=)__^G.0`!P.7___`QI_3_->,@D`@``J>$_KBG.0``[!(\OP!5IX0`/:=)
M``^Y"0!!YP0@```WISL`$.<``#``@:>$``SG`R````:G.P`0YP``,`"!IW3_
M^.<0``<`(;F$`!&Y(``404!``;GB(#2G)``8XQ,?\/]Q[!S^AP-]XS$O_/]Q
MIP@``,`0```0IK)=`!.G%/_^N>*`@J?T_G:G20`/I_3_T95!\?JG=/\^E4/Q
M^Z=T_SJ52/'\IW3_-I5%\?VG=/\RITD``J<Y_\:Y!``IP.7__^U+N00`*;D$
M`#JG20`IP.7__^]RP!```!#7XZ#PJ``DXQ#PL``DN00`9[D$`"NG]/]T!P<'
M!P<'!P?K;_`P`"2R3P`0Q(@``#[7ZQ$`(``-XR"````6LD\`$>/P_U#_<4%@
M\*32!_"H$"C`Y?__[R2Y!`"RXR"````6P.7__^\<T@`@N;"XN00`-L`@```/
MCL#E___QK>PH``<`?)4Q(`"GA`&"P.7___E+XR"````6P.7__^\!IUD`"Z=)
M``'`,```$#O`Y?__[3?L*`%5`'SC("`0``18$(``XW`@*``$P"```#[[Y5P@
M```!I\0`;Z>X``"G]``9XR`@$``$IP@``,0]```^ZK)=`"JG%/_^IW0`5^PK
M``$`V*>Z``+L.P%6P'88LKD6`"'LJP`!`-C`Y?__[L&Y!``WIUD``+D4`$O`
MY?__[CBY!`"2["@!,@!\XR`@```$Q$@``#[!6#`@#+D4`*I8$(``ZZH``P`-
MP#L`(`0`XZI````$IT@$`.PT_[R`=KD6`"'`Y?__[I3C,)````2G60`"ITD`
M`,#E___O2J<(``!8$(``Q#T``#Z5LET`*J<4__ZGA/^M["/__P#8["L`OH!V
MN18`(<#E___N<J=9``.G20`!P#````^OP.7__^RHN00`LNPH`!\`?.,@@```
M%L#E___N7>,0L!``!,!````/G.,P$```!,#E___LH>,0L!``!.,0$```!)%`
M$`VG=`#OXR"````6P.7__^Y!IUD``Z=)``'`,```#X+`Y?__['>Y!`"R["@`
M(0!\N00`-L`@```.C,#E___PQKD$`*+C((```!;LJ`"W`'S`Y?__[A_C$+`0
M``2Y!`!*XS`0```$P.7__^QDXR"````6P.7__^X.N00`LN,@@```%L#E___N
M!J=)``'`,```#TK`Y?__ZU[`0```#T^Y!``RN00`*\#E___L1.,@@```%L#E
M___M[I(`(+FY!``VP"````Y!P.7___"`Q"L``#WYN00`LNPH`$$`?+D$`"NG
M.0'`P.7__^TU["@`"1%^[!(``0#8[!(`B0%_LD\`$.L1`"``#;)/`!'5!_"H
M$"BG=`!YZV_PX``$!_[L//]%`7ZGN``!N18`(:>Z``'`Y?__[;"Y!``WP.7_
M_^O;6!"``,:]```]N*=$_^^G]/\M6!"``*?T_RG$*```/:_`Y?__^=S$*P``
M/:VY!`"R[";_MP!\P"````[DP.7__^V:E0`@`:>$_H&G]/Y\Q#T``#V36!"`
M`.PC__\`V.PK_P5@=J?T_[T8LNPC__\`V.PK_OQ@=J?T_[3`Y?__[6OC(+`0
M``3$&```/7GC("````3C,!````3`Y?__\^"G]/](XR"````6P.7__^U4XQ"P
M$``$XS`0```$P.7__^SKI_3_!,#E___L]L08```]5[D$`%+C,!````2Y!`!+
MP"````ZAP.7__^U&!P<'!P<'!P<'!P<'!P?KK_!0`"3C\/]8_W&Y!`"BP.7_
M__:PXQ`@``"0[!@`,P!\&#&Y!`"R0C#PI^,0(`$`D)4O\*=!("`!&#&YXH"R
M[!;_]`!\P.7___@=["@`%P!^[*@`%`!\E0"@`*>$``^Y!``KITD`!,`P```-
MS<#E___K9>PH``L`?NNO\/@`!`?^N00`LJ?T_^"Y!``JZZ_P^``$P/3___(.
M!P<'!P<'LD\`$.MO\#``).L1`"``#;)/`!'C\/S0_W%!L"`XT@?S*!`HIUD`
M"$$0\*BY!`!!XS"P```$ITL`$.L#`"``#.,`3_#_),`Z`````.,P3_C_)$&P
ML`BG5__MITD`0.,P$&@`!*<;``CC,!`X`(+C,!`(`(+C,!_X_X+L4R"_(5GL
M4R`^`5;C4!!X`"2G1__IXT`@```$XP`@&``$[!0@OR59XP#PH``D[!0@.@56
MXW#PL``$XS#PJ``$XU`@$``$X[`@"``$PGI:@GF9PCI:@GF9N0@`<.,P("``
M".N+``(`#+D(`!/LBP`A'E:YYP`U[)@@OP!5N8``.[GGD-6Y@@`PN8``U+D(
M`!.Y@@#5N0@`U^QQ(+\`5>P1.[\E6>P7`#H%5KD(`-'L'3N_)5GCH/"X``3K
M9``"``SL'1LZ!5;"JEJ">9FY"`"E[&0`(1Y6N>=@.+F``#>Y@@`YN0@`.KD(
M`#'LHSN_)5GLHQLZ!5;C$/#```3LC2"_`%7"&EJ">9GKUP`"``SLUP`A'E:Y
M"`"1N00`?>S6(+\`5;GG<!:Y@``8N8(`';D(`!FY"``:[*$[OR59XY#PR``$
M[*$;.@56PII:@GF9P#H`````N>C0">MH``(`#.S7(+\`5>QH`"$>5KGG8)>Y
M@`"3N8(`G;D(`)"Y"`":[*D[OR59[*D;.@56XX#PT``$P!H`````PHI:@GF9
MZW,``@`,N>C0".QS`"$>5NS6(+\`5;GG<(:Y@`"!N8(`C;D(`("Y"`"*[*@[
MOR59[#D@OP!5XY#PV``$[*@;.@56PII:@GF9ZV$``@`,N>C0">QA`"$>5NS7
M(+\`5;GG8)>Y@`"3N8(`G;D(`)"Y"`":[*D[OR59[!@@OP!5[*D;.@56XX#P
MX``$ZW,``@`,PHI:@GF9[',`(1Y6N>C0".S6(+\`5;GG<(:Y@`"!N8(`C;D(
M`("Y"`"*[*@[OR59[*@;.@56[#D@OP!5XY#PZ``$ZV$``@`,PII:@GF9[&$`
M(1Y6N>C0">S7(+\`5;GG8)>Y@`"3N8(`G;D(`)"Y"`":[*D[OR59[!@@OP!5
MXX#P\``$[*D;.@56PHI:@GF9ZW,``@`,N>C0".QS`"$>5NS6(+\`5;GG<(:Y
M@`"!N8(`C;D(`("Y"`"*[*@[OR59[#D@OP!5[*@;.@56XY#P^``$ZV$``@`,
MPII:@GF9[&$`(1Y6N>C0">S7(+\`5;GG8)>Y@`"3N8(`G;D(`)"Y"`":[*D[
MOR59[*D;.@56[!@@OP!5XX#Q```$ZW,``@`,PHI:@GF9[',`(1Y6N>C0".S6
M(+\`5;GG<(:Y@`"!N8(`C;D(`("Y"`"*[*@[OR59[#D@OP!5XY#Q"``$[*@;
M.@56PII:@GF9ZV$``@`,N>C0">QA`"$>5NS7(+\`5;GG8)>Y@`"3N8(`G;D(
M`)"Y"`":[*D[OR59[!@@OP!5[*D;.@56XX#Q$``$ZW,``@`,PHI:@GF9[',`
M(1Y6N>C0".S6(+\`5;GG<(:Y@`"!N8(`C;D(`("Y"`"*[*@[OR59[*@;.@56
M[#D@OP!5XY#Q&``$ZV$``@`,PII:@GF9[&$`(1Y6N>C0">S7(+\`5;GG8)>Y
M@`"3N8(`G;D(`)"Y"`":[*D[OR59[!@@OP!5XX#Q(``$[*D;.@56PHI:@GF9
MZW,``@`,N>C0".QS`"$>5NS6(+\`5;GG<(:Y@`"!N8(`C;D(`("Y"`"*[*@[
MOR59[#D@OP!5[*@;.@56XY#Q*``$ZV$``@`,PII:@GF9[&$`(1Y6N>C0">S7
M(+\`5;GG8)>Y@`"3N8(`G;D(`)"Y"`":[*D[OR59[*D;.@56[!@@OP!5XX#Q
M,``$ZW,``@`,PHI:@GF9[',`(1Y6N>C0"+D$`-?L=B"_`%6YY]"&N8``@;F"
M`(>Y"`"`N0@`BNRH.[\E6>-@\3@`!.RH(#H%5L)J6H)YF>PY(+\`5;GH<`;K
MD0`"``SL;2"_`%7LD0`A'E;L&""_`%6YYY!]XX#Q0``$N8``<[F"`':Y"`!P
MN0@`>NRG.[\E6<**6H)YF>RG(#H%5KD(`&CKTP`"``SLB2"_`%7LTP`A'E:Y
MY]`YXY#Q2``$N8``,<*:;MGKH;F"`#BY"`"8N0@`-NR'(K\^6>R'`B$>5KD(
M`#KLHSN_)5GK80`"``SLHR`Z!5;L80`A'E:YYV`=N8(`<>,0\5``!+D:`)>Y
MZ*!YN>>`INR7.[\E6<(:;MGKH>R7(#H%5KD:`!VYYS#:[*,BOSY9[*,"(1Y6
MN1H`';D(`!GCD/%8``3L,3N_)5FY!`#:N>>@J.PQ(#H%5L*:;MGKH;D:`):Y
MYW!J[*<BOSY9N1H`EKD(`)/LIP(A'E;C,/%@``3".F[9ZZ&Y&@`XN00`:NRI
M.[\E6;GG8'WLJ2`Z!5:YYQ"'['$BOSY9N1H`..QQ`B$>5KD(`#KLHSN_)5GL
MB2*_/EGLHR`Z!5;LB0(A'E;C$/%H``3"&F[9ZZ&Y&@`=N>=PUKF"`)VY&@`9
MXY#Q<``$N0@`&L*:;MGKH>RA.[\E6;D:`);L8R*_/EGLH2`Z!5;L8P(A'E:Y
MYX#7N8(`T^,P\7@`!+D:`)VY"`":N>=@J,(Z;MGKH;D:`#>YYQ!Z[*$BOSY9
MN1H`-^S9.[\E6>RA`B$>5NS9(#H%5N,0\8``!,(:;MGKH;D$`'JYYZ"FN1H`
M&+GGD(KLJ2*_/EFY&@`8N0@`/>RI`B$>5N.0\8@`!.S3.[\E6<*:;MGKH>S3
M(#H%5KD$`(JYYZ"GN1H`EKGG,&KLHR*_/EFY&@"6[*,"(1Y6XS#QD``$N0@`
M'<(Z;MGKH;D:`#>Y!`!JN>>@J+GG$'KLH2*_/EGLT3N_)5GLH0(A'E;LT2`Z
M!5;C$/&8``2Y&@`WPAINV>NAN00`>KGGH*:Y"`"=N1H`&+GGD(KLJ2*_/EGL
MJ0(A'E;LV3N_)5FY&@`8[-D@.@56XY#QH``$N00`BKGGH*?"FF[9ZZ&Y"``]
MN1H`ENS3.[\E6;GG,&KLHR*_/EGLTR`Z!5;LHP(A'E;C,/&H``2Y&@"6PCIN
MV>NAN0@`';D$`&KLT3N_)5GLT2`Z!5:YYZ"HN1H`-[GG$'KLH2*_/EFY"`"=
M[-D[OR59[*$"(1Y6[-D@.@56XQ#QL``$N1H`-\(:;MGKH;D$`'JYYZ"FN1H`
M&+GGD(KLJ2*_/EFY"``][*D"(1Y6[-,[OR59XY#QN``$N1H`&.S3(#H%5KD$
M`(JYYZ"GPIINV>NAN1H`EKGG,&KLHR*_/EGLHP(A'E:Y"``=[-$[OR59XS#Q
MP``$[-$@.@56N1H`EKD$`&JYYZ"HPCINV>NAN1H`-[GG$'KLH2*_/EFY"`"=
M[-D[OR59[*$"(1Y6[-D@.@56XQ#QR``$N1H`-\(:;MGKH;D$`'JYYZ"FN0@`
M/;D:`!CLTSN_)5FYYY"*[-,@.@56[*DBOSY9N1H`&..`\=``!.RI`B$>5KD(
M`!WLTR*_/EG"BF[9ZZ'LTP(A'E:Y!`":[*$[OR59N1H`ANRA(#H%5KGGD&>Y
M@@`VXV#QV``$N1H`@\)J;MGKH;GHH#BY&@!G[(,@OP!5N>?0>>RC.[\E6;F"
M`''LJ``Z!5:Y&@!GN00`>NRA(K\^6>RA`B$>5KD(`&?C$/'@``3K"``"``S"
M&F[9ZZ&Y!`!Z[*8[OR59[*8;.@56N1H`&;GG<)VY@@`YN1H`$[GHH#'L$SN_
M)5GL$QLZ!5;CH/'H``3`:@````#"JH\;O-RY&@"MN00`D.R8`"$>5KD$`(FY
MYI"7[-@@OP!5N8``EKGDT`>Y@0"0N0@`FKD(`)'LJ3N_)5GLJ1LZ!5;C$/'P
M``3`.@````#"&H\;O-RY&@`7L\$`(;/-``+K=@`"``SL=@`A'E:YYG`8N>30
MA[F``!.Y@0`8N0@`$+D(`!KLH3N_)5GLH1LZ!5;C@/'X``3`F@````#"BH\;
MO-SK8P`"``RYZ-`([&,`(1Y6[-8@OP!5N>9@A[GDT#>Y@`")N8$`@^,P\@``
M!+D(`("Y"`"*[*@[OR59[*@;.@56PCJ/&[S<N1H`-[/!`".SS0`"P!H`````
MZWD``@`,['D`(1Y6N>30E[GF<#:Y@``QN8$`.;D(`#"Y"``Z[*,[OR59XY#R
M"``$[*,;.@56PIJ/&[S<P(H`````N>C0">MA``(`#.QA`"$>5NS6(+\`5;GF
M8)>YY-`7N8``F+F!`)&Y"`"0N0@`FNRI.[\E6>,0\A``!,`Z`````.RI&SH%
M5L(:CQN\W+D:`!>SP0`AL\T``NMX``(`#.QX`"$>5KGDT(>YYG`6N8``$[F!
M`!BY"``0N0@`&NRA.[\E6>-@\A@`!,":`````.RA&SH%5L)JCQN\W.N#``(`
M#+GHT`;L@P`A'E;L:""_`%6YYH#7N>1@-[F``-FY@0#3N0@`T+D(`-KLK3N_
M)5GLK1LZ!5;C,/(@``3`&@````#".H\;O-RY&@`WL\$`([/-``+K>0`"``SL
M>0`A'E:YY&"7N>9P.+F``#&Y@0`YN0@`,+D(`#KLHSN_)5GLHQLZ!5;C@/(H
M``3KD0`"``S"BH\;O-SLD0`A'E:YZ&`([(D@OP!5N>2`%\#:`````+GFD&>Y
M@`!MN8$`8>,0\C``!+D(`&"Y"`!J[*8[OR59[*8;.@56PAJ/&[S<N1H`%^M]
M``(`#+/!`"'L?0`A'E:SS0`"N>9P&;GD@)?`.@````"Y@``3N8$`&>.0\C@`
M!+D(`!"Y"``:[*$[OR59[*$;.@56PIJ/&[S<N0@`B<!J`````.O3``(`#.S3
M`"$>5KGFT)>Y!``]N8``EL#:`````+GDT`>Y@0"0N0@`F..`\D``!+D(`)K"
MBH\;O-RSP0`(L\T``,`:`````.N&``(`#.R&`"$>5NQI(+\`5;GDT*BY@0`X
MN8``,;D:``>Y@0`ZN0@`,.QY.[\E6>.@\D@`!.QY&SH%5NN1``(`#.R1`"$>
M5L*JCQN\W+D(`*VYZ'`3[#$[OR59[#$;.@56[-D@OP!5N>:0>+GDT`BY@`!V
MN8$`<+D(`'JY"`!S[*<[OR59XS#R4``$[*<;.@56PCJ/&[S<N1H`.+/!`".S
MS0`"ZX8``@`,[(8`(1Y6N>:`.;GDT)C`&@````"Y@``QN8$`.;D(`#"Y"``Z
M[),[OR59XZ#R6``$[),;.@56ZP$``@`,[`$`(1Y6P'H`````N>8`:+D$`!"Y
M@`!GPJJ/&[S<N0@`K>S0(+\`5;GDT`BY@0!@N0@`:KD(`&GCD/)@``3LICN_
M)5GLIALZ!5;"FH\;O-RY&@"8ZX<``@`,L\$`*>R'`"$>5KGF@)&YY-`8P#H`
M````N8``D[F!`)&SS0`2XW#R:``$N0@`D;D(`)KLJ3N_)5GLJ1LZ!5;">H\;
MO-SK$P`"``RYZ-`'[!,`(1Y6[-$@OP!5N>30.,!J`````+GF$'BY@`!VN8$`
M<^,P\G``!+D(`'"Y"`!Z[*<[OR59PCJ/&[S<[*<;.@56N1H`..N&``(`#+/!
M`"/LA@`A'E:YYH`QN>30&,":`````+F``#FY@0`QL\T`$N-@\G@`!+D(`#&Y
M"``Z[*,[OR59PFJ/&[S<[*,@.@56P'H`````N0@`UNL9``(`#.P9`"$>5NQA
M(+\`5;GF$)BYY&`(N8``E[F!`)"Y"`"=N0@`FN.@\H``!.S9.[\E6<*JCQN\
MW+D:`*CLV2`Z!5;KAP`"``SLAP`A'E:YY&!XP#H`````N8$`&+F``!.Y@0`7
MXW#RB``$N0@`&L)ZRF+!UKD(`!VY"`!G[*$[OR59['DBOSY9Z],``@`,['D"
M(1Y6[*$@.@56[-,`(1Y6N>?0.+F"`)/C,/*0``2Y&@!IN>B@EKGG<*WL:3N_
M)5G".LIBP=;L:2`Z!5:Y&@`XN><0BNRA(K\^6>RA`B$>5N,0\I@`!+D:`#BY
M"``VPAK*8L'6N00`BNRC.[\E6>RC(#H%5KGG@&>Y&@`=N>>0UNQI(K\^6;D:
M`!WL:0(A'E:YZ*"1XQ#RH``$[-D[OR59[-D@.@56N>=@J,(:RF+!UKD:`!>Y
MYS!Z[*,BOSY9N1H`%^RC`B$>5N,P\J@`!+D(`!W".LIBP=:Y&@`XN00`>KGG
MH*:YYY"*[*DBOSY9N1H`..RI`B$>5N.0\K``!.S1.[\E6<*:RF+!UNS1(#H%
M5KD$`(JYYZ"GN1H`EKGG$&KLH2*_/EFY"``][*$"(1Y6XQ#RN``$N1H`ENS3
M.[\E6>S3(#H%5KD$`&JYYZ"HPAK*8L'6N1H`%[GG,'KLHR*_/EGLHP(A'E:Y
M"`"=XS#RP``$[-D[OR59[-D@.@56N1H`%[D$`'JYYZ"FPCK*8L'6N1H`.+GG
MD(KLJ2*_/EFY"``=[-$[OR59[*D"(1Y6[-$@.@56XY#RR``$N1H`.,*:RF+!
MUKD$`(JYYZ"GN1H`EKGG$&KLH2*_/EFY"``][*$"(1Y6[-,[OR59XQ#RT``$
MN1H`ENS3(#H%5KD$`&JYYZ"HPAK*8L'6N1H`%[GG,'KLHR*_/EGLHP(A'E:Y
M"`"=[-D[OR59XS#RV``$[-D@.@56N1H`%[D$`'JYYZ"FPCK*8L'6N0@`';D:
M`#CLT3N_)5FYYY"*[*DBOSY9[-$@.@56[*D"(1Y6XY#RX``$N1H`.,*:RF+!
MUKD(`#VY!`"*[-,[OR59[-,@.@56N>>@I[D:`):YYQ!J[*$BOSY9N1H`EKD(
M`)WLH0(A'E;LV3N_)5GC$/+H``3LV2`Z!5;"&LIBP=:Y!`!JN>>@J+D:`!>Y
MYS!Z[*,BOSY9[*,"(1Y6N1H`%[D(`!WLT3N_)5GLT2`Z!5;C,/+P``2Y!`!Z
MN>>@IL(ZRF+!UKD:`#BYYY"*[*DBOSY9N1H`.+D(`#WLJ0(A'E;LTSN_)5GC
MD/+X``3LTR`Z!5;"FLIBP=:Y!`"*N>>@I[D:`):YYQ!J[*$BOSY9[*$"(1Y6
MN1H`EKD(`)WLV3N_)5GLV2`Z!5;C$/,```2Y!`!JN>>@J,(:RF+!UKD:`!>Y
MYS!Z[*,BOSY9N1H`%[D(`!WLHP(A'E;LT3N_)5GC,/,(``3LT2`Z!5;".LIB
MP=:Y!`!ZN1H`.+GGH*:YYY"*N1H`.+D(`#WLTSN_)5GLJ2*_/EGLTR`Z!5;L
MJ0(A'E;LD2*_/EGL@R*_/EGLD0(A'E;L@P(A'E:SP0`-X]#S$``$L\T``,+:
MRF+!UKD:`-:YYZ!GN8(`%KD:`-'C$/,8``2Y"`#0XP#PH``$PAK*8L'6N1H`
M%[GGD'JY@@`W[&T@OP!5N1H`$^Q].[\E6>QV`#H%5KD(`!?L,3N_)5GL,1LZ
M!5:R3P!PZW<`(``-LD\`<;/!``.YYX`YN8(`T^,P\R``!,(ZRF+!UKD(`#2S
MS0!`N1H`.KD:`#VY"``TP#H`````XS`@```DN0@`&\`:`````.,0(`@`)+D(
M``BY!``YP`H`````XP`@&``DXS`@(``(ZQ8``@`,P#H`````XS`@(``D[!8`
M(1Y6N0@`%<`:`````.,0(!``)-4'\RAP**=T``;K;_-@``0'_L#E___A@`<'
MZ^_P<``DIRD`@./P_V#_<<#E___?E,`Q9T4C`>,P(```),`_[\VKB>,P(`@`
M),`_F+K<_N,P(!``),`Q$#)4=N,P(!@`).5(("@``.5((#```.5,('@``,`_
MP]+A\.,P("``).OO\1``!`?^!P<'!^MO\#``)+D$`)+C("`H``3K%``#``VY
M"``2[%$@OP!5N00`A./P_V#_<>-`D#``!+D$`+.Y,0`AI\0`!*=+``'C4)`H
M`"3K&``=``RY"``4XQ"0,``D07"0..,0D'@`$J=T`#;LC`!;/W[L:/_``-CL
M%B"Y`%6(8``&ZZ$`!@`,0=&P0*>K``'2/W``L`"Y!``I0;"P0,#E___T;:>G
M__:GBO_`B6``!AN&N10`B+D$`#VY!``GN00`2,#E___AYU"`D'CK;_#0``0'
M_J>H`$`;H1FHN00`)[GRL*BY&``AN10`:KD$`#NY!`!&P.7__^'.&!I:$)!X
M4!"0>.P6_^1`?AN*N00`*;D(`+:Y%`"(P.7___0PI_3_I[D$`-NG]/_(!P<'
M!P<'!P<'!P<'!P?KC_!``"3CD#`H``2Y!`"SXX`P,``$[#DZOSU9N10`$T$1
ML#B2@!``ISH``>/P_V#_<;D4`!.Y!`"B01&P..P\`%TX?J=(`$"Y^3`D[$,`
M$(!VIRK__^LR``@`WNPV`&T`?KD6`"+&(````'&Y!``KP.7___/HUS>P.+`X
M0H"P<T*0L'?K&``8``Q"$+!PZQ@`$``,0A"P<>L9`!@`#$(0L'3KB``(``Q"
M@+!RZQD`$``,0A"P=>N9``@`#$*0L':Y!``KP.7___.^T@.@`+`$N00`*](#
MH`2P#-(#H`BP%-(#H`RP'-(#H!"P).N/\.``!,#T___@PZ=(`#BY^3`D[$/_
MOH!VIRK__^LR``@`WNPV``H`?KD6`"+&(````!JG]/^NU_\0`!``01`1`*<V
M__NG]/_RU_\0`!``01`1`*<V__NG]/^/UP`0`!``UP`0`!``!P<'!P<'!P<'
M!P<'ZW_P.``DX_#_8/]QN00`DKD$`(.Y!`!TP.7__]U`P+```"W9P!```"W2
MN0D`L>N[``,`"NRX`!,`?+D$`*'C$*````2Y!`!'N00`.+D$`"FGJP`(#>&G
MM__TZW_PV``$!_X'!P<'!P<'!P<'!P<'!P?^!P<'!P<'!P<'!P<'!P?$6```
M+]S`]/__W>D'!P<'ZV_P,``DN00`'Z?[_V#C$/```"3`P```+J('!^-`\1``
M!.MO\-``!`?T!P<``@`!+W1M<```+@!005)?5$U01$E2``!414U01$E2`%1-
M4`!54T52``!54T523D%-10``+BX``"5S+R5S`"]P<F]C+W-E;&8O97AE``!$
M>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/
M3U0``"]P<F]C+R5I+R5S`&5X90!005)?5$5-4```4$%27U!23T=.04U%```Z
M`"\`4$523#5,24(``%!%4DQ,24(`4$523#5/4%0``%!%4DQ)3P``4$%27TE.
M251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"54<`4$%2
M7T-!0TA%`%!!4E]'3$]"04Q?1$5"54<``%!!4E]'3$]"04Q?5$U01$E2`%!!
M4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.``!005)?0TQ%04X]```Q
M`$Q$7TQ)0E)!4EE?4$%42`!365-414T``"4P,G@``"5S)7,E<R5S``!P87(M
M```E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@
M:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P
M97)A=&EO;BD*``!0051(``!P87)L```N<&%R```E<R5S8V%C:&4M)7,E<P``
M)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S``!!4D=6```8`'!E<FP`
M`#``4$%2.CI086-K97(Z.E9%4E-)3TX``#$N,#0Y`%5N86)L92!T;R!C<F5A
M=&4@8V%C:&4@9&ER96-T;W)Y```E<SH@8W)E871I;VX@;V8@<')I=F%T92!C
M86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```M90``
M+2T``&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")]
M)PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G
M92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1P87)?=&5M<"P@)'!R;V=N
M86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*
M<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR
M97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M
M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S
M(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@
M>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I
M<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I
M;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^
M("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D
M=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R
M:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=
M.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP
M)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID
M;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P
M+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G
M(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I
M.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O
M<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@
M>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L
M<SHZ4$%2.CI"3T]4.PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PIE=F%L
M('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"
M54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>
M35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O
M7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM
M("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P*
M*3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A
M<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]705).7U]](#T@
M<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN
M;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1P<F]G;F%M93L*
M;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1M86=I8U]P;W,["FEF
M("@D<VEZ92`\/2`D8VAU;FM?<VEZ92D@>PHD;6%G:6-?<&]S(#T@,#L*?2!E
M;'-I9B`H*&UY("1M(#T@)'-I>F4@)2`D8VAU;FM?<VEZ92D@/B`P*2!["B1M
M86=I8U]P;W,@/2`D<VEZ92`M("1M.PI](&5L<V4@>PHD;6%G:6-?<&]S(#T@
M)'-I>F4@+2`D8VAU;FM?<VEZ93L*?0IW:&EL92`H)&UA9VEC7W!O<R`^/2`P
M*2!["G-E96LH7T9(+"`D;6%G:6-?<&]S+"`P*3L*<F5A9"A?1D@L("1B=68L
M("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I*3L*:68@*"AM>2`D
M:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PHD;6%G:6-?
M<&]S("L]("1I.PIL87-T.PI]"B1M86=I8U]P;W,@+3T@)&-H=6YK7W-I>F4[
M"GT*;&%S="!I9B`D;6%G:6-?<&]S(#P@,#L*<V5E:R!?1D@L("1M86=I8U]P
M;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("1M86=I
M8U]P;W,@+2`T("T@=6YP86-K*").(BP@)&)U9BDL(#`["B1D871A7W!O<R`]
M('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@
M-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T
M(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@
M)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U
M;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA
M+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D
M97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@
M7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U
M9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L
M?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1C<F,D
M97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U
M;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^
M(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*
M;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8F%S96YA;64D97AT(BP@)&)U
M9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@
M>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D
M=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D
M8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@
M-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@
M/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D
M:6YF;R`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5](&]R(')E='5R
M;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII
M9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W
M*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A
M.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D:6YF;RT^>V)U9GT["G-E96LH
M)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE
M(#T@7W1E;7!F:6QE*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI
M.PIO<&5N(&UY("1F:"P@)SPG+"`D9FEL96YA;64@;W(@9&EE(")C86XG="!R
M96%D("1F:6QE;F%M93H@)"$B.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D9F@[
M"GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO
M9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E
M(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP
M;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R
M="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL
M96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N
M86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS
M92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S
M=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N
M86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T
M87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T
M87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L
M("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%
M55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O
M8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H
M(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F
M)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A
M<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?
M<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@
M97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D55
M4T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H
M879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;
M,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@
M*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H
M)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!
M)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/
M)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE
M(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A
M;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I
M9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@
M(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4
M)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY
M("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-
M4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$
M:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M
M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A
M9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE
M.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*
M?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE
M9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN
M;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L
M("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II
M<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B
M.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z
M:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R
M.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;
M7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I
M;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D
M<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I
M;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T
M:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&
M:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&
M:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F
M:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U
M;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&
M2#X["FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>
M*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R
M+"`D,"D*?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY
M("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@
M:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@
M+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y
M*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC
M("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI
M"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H
M)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I
M;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S
M*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N
M9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H
M;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]
M*3L*?2!`24Y#.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,
M;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI
M8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["FUY("5W<FET=&5N
M.PIF;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D;F%M92P@)&9I
M;&4I.PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1N86UE(#T@)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*
M?0IE;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL
M92P@)&YA;64I(#T@*"0Q+"`D,BD["FQA<W0["GT*96QS:68@*&TA7B]L;V%D
M97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ
M2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D
M<F5F+"`D,2D["FQA<W0["GT*96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I
M;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X
M="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE
M?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L
M:6)?97AT7$4D+SL*;W5T<R@@:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F
M("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM
M>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL
M92T^>V)U9GT["GT*96QS92!["F]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D
M:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O
M;G1E;G0@/2`\1DE,13X["F-L;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13
M=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0II9B`A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD[
M"E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT
M96YT+"`D9FEL92P@)&YA;64I.PI]"F]U=',H<7$H5W)I='1E;B!A<R`B)&YA
M;64B*2D["B1F:"T^<')I;G0H(D9)3$4B*3L*)&9H+3YP<FEN="AP86-K*"=.
M)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*)&9H+3YP<FEN="AS<')I;G1F*`HB
M)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT
M*2P@)&YA;64**2D["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N
M=&5N="DI*3L*)&9H+3YP<FEN="@D8V]N=&5N="D["GT*?0HD>FEP+3YW<FET
M951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B
M<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@
M;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C='@@/2!$:6=E
M<W0Z.E-(02T^;F5W*#$I.PIO<&5N*&UY("1F:"P@(CPB+"`D;W5T*3L*8FEN
M;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C
M86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE("X]
M(")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M
M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N86UE*3L*)&9H+3YP
M<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D[
M"B1F:"T^<')I;G0H)%!!4E]-04=)0RD["B1F:"T^8VQO<V4["F-H;6]D(#`W
M-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R
M=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0[
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN
M97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII
M<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N
M;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*07)C:&EV93HZ6FEP.CIS
M971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^
M;F5W.PHD>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["D%R
M8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!
M4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@
M/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD
M14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN
M960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@
M<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2![
M"FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M
M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA
M;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO
M;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI
M"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]
M($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T
M7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M
M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M
M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N
M86UE(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?
M;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I
M;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@
M:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A
M8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S
M86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@
M6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U
M=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA
M;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY
M("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B
M87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P
M87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I
M;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M
M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R![
M"G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT
M96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I
M<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR
M97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER
M92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP
M.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I
M<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I
M;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ
M6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER
M92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H
M0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#
M=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@
M4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP
M.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P
M='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/
M.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T
M7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%
M3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T
M=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@
M4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z
M7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H
M(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@
M)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I
M;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2![
M"B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I
M;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U
M<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-9
M4U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]
M("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E
M<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#
M3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2![
M"F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PIS965K("1F:"P@+3$X
M+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*:68@*"1B=68@97$@(EPP
M0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y<W)E860@)&9H+"`D8G5F
M+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?
M9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS92!["FUY("1D:6=E<W0@/2!E
M=F%L"GL*<F5Q=6ER92!$:6=E<W0Z.E-(03L*;7D@)&-T>"`]($1I9V5S=#HZ
M4TA!+3YN97<H,2D["F]P96XH;7D@)&9H+"`B/"(L("1P<F]G;F%M92D["F)I
M;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PHD
M8W1X+3YH97AD:6=E<W0["GT@+R\@)&UT:6UE.PHD<W1M<&1I<B`N/2`B)$-O
M;F9I9WM?9&5L:6U]8V%C:&4M)&1I9V5S="(["GT*8VQO<V4H)&9H*3L*?0IE
M;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF
M:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D
M:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]
M("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O
M*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D;F%M92P@)&-O;G1E;G1S
M+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M
M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D
M9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@)SXG+"`D=&5M<&YA;64@;W(@
M9&EE(")C86XG="!W<FET92`D=&5M<&YA;64Z("0A(CL*8FEN;6]D92`D9F@[
M"G!R:6YT("1F:"`D8V]N=&5N=',["F-L;W-E("1F:#L*8VAM;V0@)&UO9&4L
M("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE
M+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D
M9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D
M14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O
M*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*
M:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[
M4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA
M;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*
M?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L
M("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\
M)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D
M<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I
M9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O
M7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF
M(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]4
M14U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R
M;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG
M>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@
M>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H
M:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O
M9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W
M9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@
M*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z
M(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN
M/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD
M14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI
M=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2![
M"G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*
M?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/
M1TY!344@*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W
M+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1?
M?2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!
M4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?
M0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@
M>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%
M3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P
M87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%
M04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]
M"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP
M<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*
M?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G
M<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C
M:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N
M9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E
M<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2
M+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E
M;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I
M<F5C=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64[
M"D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI
M+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]
M"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<
M*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*
M7U]%3D1?7PH``'!E<FQX<VDN8P!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@
M("`@("`@(````1L#.P```/0````=__^$````!6C__X9@```!$/__AY````%`
M__^(@````:#__XE````!T/__C+````(0__^.L````DS__X]@```"?/__D*``
M``*\__^0X````MS__Y%````#&/__DD````-<__^24````W#__Y4@```#L/__
ME7````/0__^6X````_3__YB````$)/__F2````1(__^94```!&C__YK@```$
MI/__H^````3L__^H````!2S__ZB@```%J/__OL````7H__^_,```!@S__\!@
M```&2/__P<````:`___",```!KC__\)````&T``````````4``````%Z4@`!
M>`X!&PP/H`$'#@`````4````'/__A4@```!&```````````````4``````%Z
M4@`!>`X!&PP/H`$```````!<````'/__AD@```#B`$:&#H<-B`R)"XH*BPF,
M"(T'C@:/!48.R`("G@K/SLW,R\K)R,?&#J`!0@M<"L_.S<S+RLG(Q\8.H`%"
M"TX*S\[-S,O*R<C'Q@Z@`4(+```````L````?/__AM@```"V`$J*"HL)C`B-
M!XX&CP5&#M`"`IX*S\[-S,O*#J`!0@L````\````K/__AV@```-B`$J&#H<-
MB`R)"XH*BPF,"(T'C@:/!48.X`(#`K@*S\[-S,O*R<C'Q@Z@`4(+````````
M.````.S__XJ8```!]@!*A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#N`#`D`*S\[-
MS,O*R<C'Q@Z@`4(+````+````2C__XQ<````I@!4BPF,"(T'C@:/!48.V`,"
MA`K/SLW,RPZ@`4(+````````/````5C__XS<```!/`!&APV(#(D+B@J+"8P(
MC0>.!H\%1@Z@(5`.R"("N@K/SLW,R\K)R,<.H`%""P```````!P```&8__^-
MW````#P`3(X&CP5&#L`"9,_.#J`!````.````;C__XW\````6@!&A@Z'#8@,
MB0N*"HL)C`B-!XX&CP5,#L@"`D;/SLW,R\K)R,?&#J`!````````0````?3_
M_XX@````_`!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#J`A3`Z@05`.V$("Q`K/
MSLW,R\K)R,?&#J`!0@L````0```"./__CMP````&`````````#P```),__^.
MV````L8`1H8.APV(#(D+B@J+"8P(C0>.!H\%1@Z@(5`.\","?@K/SLW,R\K)
MR,?&#J`!0@L````<```"C/__D6@```!0`%0)#Q!&#L@";L\.H`$``````"``
M``*L__^1F````6X``P$2C@:/!48.P`)@S\X.H`$``````"P```+0__^2Y```
M`:``2HL)C`B-!XX&CP5&#O`"`P%&"L_.S<S+#J`!0@L``````"````,`__^4
M5````)P`2HX&CP5&#M`"?@K/S@Z@`4(+`````!P```,D__^4T````"P`1HX&
MCP5&#L`"7L_.#J`!````.````T3__Y3@```!@@!4A@Z'#8@,B0N*"HL)C`B-
M!XX&CP5&#N`"`EH*S\[-S,O*R<C'Q@Z@`4(+````1````X#__Y8T```(^`!&
MA@Z'#8@,B0N*"HL)C`B-!XX&CP5&#`Z@@0)L#0]&#J"%`@,"O`K/SLW,R\K)
MR,?&#J`!0@L`````/````\C__Y[L```$$@!*A@Z'#8@,B0N*"HL)C`B-!XX&
MCP5<#M`"`P+>"L_.S<S+RLG(Q\8.H`%""P```````#@```0(__^BS````)H`
M1HH*BPF,"(T'C@:/!48.R`("=`K/SLW,R\H.H`%""U+/SLW,R\H.H`$`````
M`#P```1$__]^D````EX`2H8.APV(#(D+B@J+"8P(C0>.!H\%1@[H`@,!O@K/
MSLW,R\K)R,?&#J`!0@L````````\```$A/__HO```!8>`%2&#H<-B`R)"XH*
MBPF,"(T'C@:/!48.T`<#%?P*S\[-S,O*R<C'Q@Z@`4(+````````(```!,3_
M_[C0````;`!*C@:/!48.P`("6L_.#J`!````````.```!.C__[D<```!(@!&
MA@Z'#8@,B0N*"HL)C`B-!XX&CP5D#L`"`J`*S\[-S,O*R<C'Q@Z@`4(+````
M-```!23__[H0```!5`!&B`R)"XH*BPF,"(T'C@:/!6P.P`("P`K/SLW,R\K)
MR`Z@`48+```````T```%7/__NS@```!B`$:'#8@,B0N*"HL)C`B-!XX&CP5&
M#L`"`E3/SLW,R\K)R,<.H`$``````!0```64__^[<`````(`````````````
M`!````6L__^[:`````P`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````ED````````"5```````````$``````````0``````
M```!`````````;P``````````0````````(+``````````P````````::```
M```````-````````8&``````````&0```````+N8`````````!L`````````
M"``````````:````````NZ``````````'``````````(`````&___O4`````
M```"D``````````%````````#+@`````````!@````````-P``````````H`
M```````$L``````````+`````````!@`````````%0``````````````````
M``,```````"]N``````````"````````!7``````````%``````````'````
M`````!<````````4^``````````'````````$J``````````"`````````)8
M``````````D`````````&``````````>``````````@`````;___^P`````(
M```!`````&____X````````2,`````!O____``````````(`````;___\```
M`````!%H`````&____D`````````#@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````NZ@`````````````````````````````&M8`
M```````:]@```````!L6````````&S8````````;5@```````!MV````````
M&Y8````````;M@```````!O6````````&_8````````<%@```````!PV````
M````'%8````````<=@```````!R6````````'+8````````<U@```````!SV
M````````'18````````=-@```````!U6````````'78````````=E@``````
M`!VV````````'=8````````=]@```````!X6````````'C8````````>5@``
M`````!YV````````'I8````````>M@```````![6````````'O8````````?
M%@```````!\V````````'U8````````?=@```````!^6````````'[8`````
M```?U@```````!_V````````(!8````````@-@```````"!6````````('8`
M```````@E@```````""V````````(-8````````@]@```````"$6````````
M(38````````A5@```````"%V````````(98````````AM@```````"'6````
M````(?8`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````(A```````````````````,`(_____P````````````!@D```
M`````&"6``````````````````!@F````````&"<````````8*0```````!A
M(````````&"L``````````````````!@L````````&"V````````````````
M``!C@D=#0SH@*%5B=6YT=2`Y+C(N,2TR-75B=6YT=3$I(#DN,BXQ(#(P,C`P
M,3(S```N<VAS=')T86(`+FEN=&5R<``N;F]T92YG;G4N8G5I;&0M:60`+FYO
M=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R
M<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET
M`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`
M+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N
M8G-S`"YC;VUM96YT````````````````````````````````````````````
M````````````````````````````````````````````````"P````$`````
M`````@````````(X`````````C@`````````#P````````````````````$`
M`````````````!,````'``````````(````````"2`````````)(````````
M`"0````````````````````$```````````````F````!P`````````"````
M`````FP````````";``````````@````````````````````!```````````
M````-&____8``````````@````````*0`````````I``````````X`````4`
M``````````````@``````````````#X````+``````````(````````#<```
M``````-P````````"4@````&`````@`````````(`````````!@```!&````
M`P`````````"````````#+@````````,N`````````2P````````````````
M`````0``````````````3F____\``````````@```````!%H````````$6@`
M````````Q@````4```````````````(``````````@```%MO___^````````
M``(````````2,````````!(P`````````'`````&`````@`````````(````
M``````````!J````!``````````"````````$J`````````2H`````````)8
M````!0``````````````"``````````8````=`````0`````````0@``````
M`!3X````````%/@````````%<`````4````5``````````@`````````&```
M`'X````!``````````8````````::````````!IH`````````$``````````
M```````````$``````````````!Y`````0`````````&````````&J@`````
M```:J`````````=@````````````````````!``````````@````A`````$`
M````````!@```````"(0````````(A`````````^4```````````````````
M`!```````````````(H````!``````````8```````!@8````````&!@````
M`````"P````````````````````$``````````````"0`````0`````````"
M````````8(P```````!@C````````#V$````````````````````!```````
M````````F`````$``````````@```````)X0````````GA``````````]```
M``````````````````0``````````````*8````!``````````(```````"?
M"````````)\(````````!?`````````````````````(``````````````"P
M````#@`````````#````````NY@```````"KF``````````(````````````
M````````"``````````(````O`````\``````````P```````+N@````````
MJZ``````````"`````````````````````@`````````"````,@````&````
M``````,```````"[J````````*NH`````````A`````&```````````````(
M`````````!````#1`````0`````````#````````O;@```````"MN```````
M``)(````````````````````"``````````(````U@````$``````````P``
M`````,``````````L```````````@`````````````````````@`````````
M`````-P````(``````````,```````#`@````````+"`````````$"@`````
M```````````````(``````````````#A`````0`````````P````````````
M``````"P@``````````M`````````````````````0`````````!`````0``
M``,`````````````````````````````L*T`````````Z@``````````````
-``````$`````````````
